// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cstdlib>
#include <cstdio>

#include "globals.hh"
#include "algo.hh"
#include "PingusGame.hh"

PingusGame::PingusGame()
{
  server = 0;
  client = 0;
}

PingusGame::~PingusGame()
{
  if (client) 
    delete client;
  if (server)
    delete server;
}

string
PingusGame::read_lastlevel_file()
{
  FILE* in;
  char* home;
  string filename;
  char levelfile[1024];

  if ((home = getenv("HOME")) != 0) {
    filename += home;
    filename += "/";
  }

  filename += ".pingus/last_level";

  in = fopen(filename.c_str(), "r");
  if (!in) {
    cout << "Warrning: Couldn't open lastlevel file, using default level1.plf" << endl;
    return find_file(pingus_datadir, "levels/level1.plf");
  } else {
    fgets(levelfile, 1023, in);
    cout << "Read lastlevel file: " << levelfile << endl;
    fclose(in);
    return string(levelfile);
  }
}

void
PingusGame::write_lastlevel_file(string levelfile)
{
  FILE* out;
  char* home;
  string filename;

  if ((home = getenv("HOME")) != 0) {
    filename += home;
    filename += "/";
  }

  filename += ".pingus/last_level";

  out = fopen(filename.c_str(), "w");
  if (!out) {
    cout << "Warrning: Couldn't write lastlevel file" << endl;
  } else {
    cout << "Writing lastlevel file: " << levelfile << endl;
    fprintf(out, levelfile.c_str());
    fclose(out);
  }
}

void
PingusGame::start(string filename)
{
  if (filename.empty()) {
    filename = read_lastlevel_file();
  }
  // Should contain code out of world.init
  server = new TrueServer;
  client = new Client(server);
  
  if (!filename.empty())
    write_lastlevel_file(filename);

  // FIXME: We are losing the Results
  client->start(filename);
}

/* EOF */
